@@ -36,7 +36,7 @@ static GtkActionEntry action_entries[] = {
 	{ "ViewMenu", NULL, N_("_View") },
 	{ "HelpMenu", NULL, N_("_Help") },
 	{ "ArrangeFilesMenu", NULL, N_("_Arrange Files") },
-	{ "RecentFilesMenu", NULL, N_("Open R_ecent") },
+	{ "OpenRecentMenu", NULL, N_("Open R_ecent") },
 
 	{ "About", GTK_STOCK_ABOUT,
 	  NULL, NULL,
@@ -103,7 +103,7 @@ static GtkActionEntry action_entries[] = {
 	  N_("Open archive"),
 	  G_CALLBACK (activate_action_open) },
 	{ "OpenSelection", NULL,
-	  N_("Open Fi_les..."), NULL,
+	  N_("Op_en With..."), NULL,
 	  N_("Open selected files with an application"),
 	  G_CALLBACK (activate_action_open_with) },
 	{ "Password", NULL,
@@ -147,7 +147,7 @@ static GtkActionEntry action_entries[] = {
 	  N_("Test whether the archive contains errors"),
 	  G_CALLBACK (activate_action_test_archive) },
 	{ "ViewSelection", FR_STOCK_VIEW,
-	  N_("_View File"), NULL,
+	  N_("_View"), NULL,
 	  N_("View the selected file"),
 	  G_CALLBACK (activate_action_view_or_open) },
 	{ "ViewSelection_Toolbar", FR_STOCK_VIEW,
@@ -215,19 +215,22 @@ static const gchar *ui_info =
 "    <menu name='Archive' action='ArchiveMenu'>"
 "      <menuitem action='New'/>"
 "      <menuitem action='Open'/>"
+"      <menu name='OpenRecentMenu' action='OpenRecentMenu'>"
+"        <menuitem action='Open'/>"
+"      </menu>"
 "      <menuitem action='SaveAs'/>"
 "      <separator/>"
-"      <menuitem action='Properties'/>"
+"      <menuitem action='Extract'/>"
 "      <menuitem action='TestArchive'/>"
 "      <separator/>"
-"      <placeholder name='RecentFilesMenu' action='RecentFilesMenu'/>"
+"      <menuitem action='Properties'/>"
+"      <separator/>"
 "      <menuitem action='Close'/>"
 "      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='EditMenu'>"
 "      <menuitem action='AddFiles'/>"
 "      <menuitem action='AddFolder'/>"
-"      <menuitem action='Extract'/>"
 "      <separator/>"
 "      <menuitem action='Cut'/>"
 "      <menuitem action='Copy'/>"
@@ -238,9 +241,6 @@ static const gchar *ui_info =
 "      <menuitem action='SelectAll'/>"
 "      <menuitem action='DeselectAll'/>"
 "      <separator/>"
-"      <menuitem action='OpenSelection'/>"
-"      <menuitem action='ViewSelection'/>"
-"      <separator/>"
 "      <menuitem action='Password'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
